==> haskell-io-streams-haproxy-1.0.0.2-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-ANUbnkiqAdz5wDiwawTm0W
key: io-streams-haproxy-1.0.0.2-ANUbnkiqAdz5wDiwawTm0W
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 5a6a008961d0d4dd40d01bdc5125a3da
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-ANUbnkiqAdz5wDiwawTm0W
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    bytestring-0.10.8.2 io-streams-1.5.0.1-EXYgzwVXtzcKQ8mQHSCEPR
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             io-streams-1.5.0.1-EXYgzwVXtzcKQ8mQHSCEPR=d160931c42329e0f3edfb55d5bc08279
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.0.2-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-8D7iZvvYZ3khHijioLZnq
key: io-streams-haproxy-1.0.0.2-8D7iZvvYZ3khHijioLZnq
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: f5179fb6d9b5aebaa9364dbfdf926b3d
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.1/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-8D7iZvvYZ3khHijioLZnq
depends:
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-GecMReDhwXu2KpH81Ly9XL
    network-2.7.0.2-AhHTxdUIBGH70CptKdvDEL transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
